Learn R Programming

intergraph (version 1.2-0)

as.matrix.igraph: Convert igraph objects to adjacency or edge list matrices

Description

Get adjacency or edgelist representation of the network stored as igraph object.

Usage

## S3 method for class 'igraph':
as.matrix(x, matrix.type = c("adjacency", "edgelist"), 
	attrname = NULL, ...)

Arguments

x
object of class igraph, the network
matrix.type
character, type of matrix to return, currently "adjacency" or "edgelist" are supported
attrname
character, name of the edge attribute to use to fill in the cells of the adjacency matrix
...
other arguments to/from other methods

Value

  • Depending on the value of matrix.type either a square adjacency matrix or a two-column numeric matrix representing the edgelist.

Details

If matrix.type is "edgelist" a two-column numeric edgelist matrix is returned. The value of attrname is ignored.

If matrix.type is "adjacency" then a square adjacency matrix is returned. If attrname is NULL (default) the matrix is binary. Otherwise attrname can be a name of edge attribute of x. In that case the cells of the results are the values of that attribute.

Other arguments passed through ... are passed to either get.adjacency or get.edgelist depending on the value of matrix.type.

See Also

get.adjacency, get.edgelist

Examples

Run this code
data(exIgraph)
as.matrix(exIgraph, "adjacency")
as.matrix(exIgraph, "edgelist")
# use edge attribute "label" 
as.matrix(exIgraph, "adjacency", "label")

Run the code above in your browser using DataLab