attrmap(newdf = NULL)newdf is NULL, a data frame with the current copy/rename rules.
Otherwise newdf are set as new rules and the old ones are returned
invisibly, much like par.The rules are stored in a data frame with the following columns (all of mode
character):
[object Object],[object Object],[object Object],[object Object],[object Object]
When converting network x, of class xclass to network y of
class yclass the coercion method looks up the rows in this table for
which fromcls=xclass and tocls=yclass. If network x has
any of the attributes listed in the fromattr in the resulting subset of
the table then, it is renamed to the corresponding value of toattr. If
toattr is NA the attribute is dropped from the result.
as.igraph and as.network