Compare or test network objects for (near) equality.
Usage
netcompare(target, current, test = FALSE, ...)
Arguments
target, current
network objects, currently network and
igraph classes are supported
test
logical, whether to perform the test or return comparison data,
see Details
...
other arguments, currently ignored
Value
Depending on the value of test either an object of class
netcompare containing the results of all the tests (if
test=FALSE) or (if test=TRUE) a logical whether or not the
networks are (nearly) the same.
Details
Arguments target and current can be network objects of
one of the supported classes. They do not have to be of the same class though.
The function does a series of comparisons between target and
current:
The network structure comparison is made based on adjacency matrices
(mind this when using for huge networks).
Network/edge/vertex attributes are checked for presence in both
objects.
Common network/edge/vertex attribures are checked for equality.
All the results are collected in a list of class netcompare
with an associated print method.
If test is TRUE then instead of the detailed test results the function
returns TRUE or FALSE depending on some of the checks resulted positively.
Currently attribute checks are ignored, i.e. what is taken into account is: